import useSettingsStore from '@/settings/useSettingsStore'
import useTimeStore from '@/utils/useTimeStore'
import { Lunar } from 'lunar-typescript'
import { computed, defineComponent, Transition } from 'vue'

export default defineComponent({
  setup() {
    const time = useTimeStore()
    const text = computed(() => {
      const h = time.date.getHours()
      const hour = h < 10 ? '0' + h : h
      const m = time.date.getMinutes()
      const minute = m < 10 ? '0' + m : m
      const s = time.date.getSeconds()
      const second = s < 10 ? '0' + s : s
      const dateStr = `${time.date.getMonth() + 1}月${time.date.getDate()}日`
      return {
        timeStr: `${hour}:${minute}:${second}`,
        dateStr
      }
    })
    const info = computed(() => {
      const l = Lunar.fromDate(time.date)
      const day = l.getMonthInChinese() + '月' + l.getDayInChinese()
      const dayWeek = l.getWeekInChinese()
      return {
        day,
        dayWeek
      }
    })

    const settings = useSettingsStore()
    return () => (
      <div class="shadow-text tracking-widest font-mono text-white/80 font-bold">
        <Transition>
          {settings.state.showDate && (
            <div class="text-[4rem] leading-[4rem]">{text.value.timeStr}</div>
          )}
        </Transition>
        <Transition>
          {settings.state.showTime && (
            <div class="flex justify-center items-center gap-4 mt-4">
              <div>{text.value.dateStr}</div>
              <div>星期{info.value.dayWeek}</div>
              <div>{info.value.day}</div>
            </div>
          )}
        </Transition>
      </div>
    )
  }
})
