import { defineComponent, reactive, watch } from 'vue'
import { Button, Form, Input } from 'ant-design-vue'
import asyncLoader from '@/utils/asyncLoader'
import { CheckOutlined } from '@ant-design/icons-vue'
const ImageUploader = asyncLoader(() => import('@/utils/ImageUploader'))

export default defineComponent({
  props: {
    selected: {
      type: Object,
      default: () => ({})
    }
  },
  setup(props) {
    const addState = reactive({
      name: '',
      url: '',
      icon: ''
    })
    watch(
      () => props.selected,
      (obj) => {
        if (!obj) {
          addState.name = ''
          addState.url = ''
          addState.icon = ''
          return
        }
        addState.name = obj.name
        addState.url = obj.url
        addState.icon = obj.icon
      },
      { immediate: true }
    )
    return () => (
      <Form
        layout="vertical"
        model={addState}
        onFinish={(res) => {
          console.log(res)
        }}
      >
        <Form.Item label="名称" name="name" rules={[{ required: true, message: '引擎名必填' }]}>
          <Input v-model:value={addState.name} />
        </Form.Item>
        <Form.Item
          label="链接"
          name="url"
          rules={[{ required: true, message: '链接必填' }]}
          help="以 %s 代替查询内容"
        >
          <Input v-model:value={addState.url} />
        </Form.Item>
        <Form.Item label="图标" name="icon">
          <ImageUploader v-model:value={addState.icon} />
        </Form.Item>
        <Form.Item class="flex justify-end mb-0">
          <Button type="primary" htmlType="submit" icon={<CheckOutlined />}>
            确认添加
          </Button>
        </Form.Item>
      </Form>
    )
  }
})
