import { type Directive } from 'vue'

const mapping = new WeakMap<Node, (e: MouseEvent) => void>()

// 确认 absolute 内容层级
export default {
  mounted(el, binding) {
    setTimeout(() => {
      const handle = (e: Event) => {
        if (el.contains(e.target as Node)) return
        binding.value()
      }
      mapping.set(el, handle)
      document.addEventListener('click', handle)
      document.addEventListener('contextmenu', handle)
    }, 0)
  },
  beforeUnmount(el) {
    const handle = mapping.get(el)
    if (!handle) return
    document.removeEventListener('click', handle)
    document.removeEventListener('contextmenu', handle)
  }
} as Directive<HTMLDivElement, () => void>
